/**
 * COOS - Connected Objects Operating System (www.connectedobjects.org).
 *
 * Copyright (C) 2009 Telenor ASA and Tellu AS. All rights reserved.
 * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
 *
 * This library is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as published
 * by the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 *
 * You may also contact one of the following for additional information:
 * Telenor ASA, Snaroyveien 30, N-1331 Fornebu, Norway (www.telenor.no)
 * Tellu AS, Hagalokkveien 13, N-1383 Asker, Norway (www.tellu.no)
 */
package org.coos.plugin.logagent.impl;

import org.coos.messaging.Consumer;
import org.coos.messaging.Processor;
import org.coos.messaging.Producer;
import org.coos.messaging.impl.DefaultEndpoint;

/**
 * The LogAgent Endpoint.
 * 
 * @author Robert Bj&aelig;rum, Tellu AS
 *
 */
public class LogAgentEndpoint extends DefaultEndpoint {
	volatile static LogAgentEndpoint lastInstance = null;
	private Consumer consumer;
	private LogAgentProducer producer;

	public LogAgentEndpoint() {
		lastInstance = this;
	}

	public LogAgentEndpoint(String uri, Processor processor) {
		super(uri, processor);
		lastInstance = this;
	}
	
	public static LogAgentEndpoint getLastInstance() {
		return lastInstance;
	}

	public Consumer createConsumer() {
		if (consumer == null) {
			consumer = new LogAgentConsumer(this);
		}
		return consumer;
	}

	public Producer createProducer() {
		if (producer == null) {
			producer = new LogAgentProducer(this);
		}
		return producer;
	}
	
	public int sendLoggingEvent(String logServerUri, byte[] serializedEvent) {
		if (producer != null) {
			return producer.sendLoggingEvent(logServerUri, serializedEvent);
		}
		return -1;
		
	}
}
