/**
 * COOS - Connected Objects Operating System (www.connectedobjects.org).
 *
 * Copyright (C) 2009 Telenor ASA and Tellu AS. All rights reserved.
 * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
 *
 * This library is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as published
 * by the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 *
 * You may also contact one of the following for additional information:
 * Telenor ASA, Snaroyveien 30, N-1331 Fornebu, Norway (www.telenor.no)
 * Tellu AS, Hagalokkveien 13, N-1383 Asker, Norway (www.tellu.no)
 */
package org.coos.plugin.logagent.impl;

import java.io.Serializable;


import org.coos.messaging.Endpoint;
import org.coos.messaging.Exchange;
import org.coos.messaging.InteractionHelper;
import org.coos.messaging.Producer;
import org.coos.plugin.logserver.api.LogMessageFactory;

/**
 * The LogAgent Producer.
 * <p>
 * Uses the LogServer API to send serialized logging events to logging server.
 * 
 * @author Robert Bj&aelig;rum, Tellu AS
 *
 */
public class LogAgentProducer implements Producer {

	private int count;
	private Endpoint endpoint;

	public LogAgentProducer(Endpoint endpoint) {
		this.endpoint = endpoint;
	}

	public int getCount() {
		return count;
	}

	protected int sendLoggingEvent(String logServerUri, byte[] serializedEvent) {
		if (++count == Integer.MAX_VALUE) {
			count = 1;
		}
		Exchange exchange = LogMessageFactory.createSendEventExchange(serializedEvent);
		InteractionHelper helper = new InteractionHelper(endpoint);
		exchange = helper.send(logServerUri, exchange);
		return count;
	}

}
